@@ -41,7 +41,7 @@ class Header(object):
 
     @property
     def proper_title(self):
-        return str(self.title).replace('_', ' ')
+        return self.title.replace('_', ' ')
 
     def __str__(self):
         return self.link_tag
